@@ -9,6 +9,9 @@ package Schedule::Depend::Test;
 
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
+#
+# test::simple has some problems due to forks, etc. Until i can 
+# work them out this is easier to hard-code.
 
 BEGIN { $| = 1; print "1..37\n"; }
 END {print "not ok 1\n" unless $loaded;}
@@ -49,10 +52,15 @@ my $tmpdir	= "$dir/tmp";
 
 my $defsched = <DATA> . 
 qq{
+	# alias
+
 	cleanup = ls -l $tmpdir/*
-	rundir	= $tmpdir
-	logdir	= $tmpdir
-	force	= 1
+
+	# attributes
+
+	rundir	% $tmpdir
+	logdir	% $tmpdir
+	force	% 1
 };
 
 my @defargz =
@@ -189,9 +197,9 @@ sub testify
 
 	for my $maxjob ( qw(1 2 0) )
 	{
-		for my $debug ( '', 'debug = 1' )
+		for my $debug ( '', 'debug % 1' )
 		{
-			my $sched = $defsched . "\n$debug" . "\nmaxjob = $maxjob";
+			my $sched = $defsched . "\n$debug" . "\nmaxjob % $maxjob";
 
 			for $sub ( keys %subz )
 			{
@@ -334,7 +342,8 @@ f = echo "f"
 # in this case "startup" has no further dependencies and will
 # be the first job run.
 
-# the normal jobs depend on our "startup" job being complete.
+# the normal jobs depend on "startup" exiting zero.
+# the final exit status will be that of cleanup.
 
 a b c d e f : startup
 
